==> cbol-1.5.tgz: cbol-1.5/lec/subread.php <==
<?php
 /**** @ܼ ********/
  //W
 require("config.php");
 $PROGNAME="read.php";
  //TableXSOѼ
  //C@
 $PGNUM=500;//ϥ@藍|500`
 // Primary Key	
 $PKEY="oid";
 /******** parse  #mt 1:1-3 *****/
 function parsed($VERSION,$tok)
 {
      $LIMIT="";
      $gtok=split("-",$tok);
      //$gtok = strtok ($tok,"-");
      $LIMIT="or ($VERSION.sec>=$gtok[0] and $VERSION.sec<=$gtok[1]) ";
      return($LIMIT);
 }
 function outbible($db_conn,$VERSION,$chineses,$chap,$sec,$chap2,$sec2)
{
 if (!isset($VERSION)) $VERSION="unv";
 if (!isset($strongflag)) $strongflag=0;
 if ($strongflag) $sf=0;
 else $sf=1;
 if (!isset($TABFLAG)) $TABFLAG=0;
 if ($TABFLAG) $TF=0;
 else $TF=1;
  $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 /*****TwO_IDܼ*******/
 if (isset($id))
 {
  $QID="select main.chineses, $VERSION.chap from $VERSION,main where main.engs=$VERSION.engs and $VERSION.id=$id"; 

  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ʈwd߿~AO $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $chineses=$ARAW[0];
  $chap=$ARAW[1];
  db_FreeResult($result);
 }
 
  //QueryO
 if ($chap2>0)  //# mt 1:1-3:4
 {
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap and $VERSION.sec=$sec"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ʈwd߿~AO $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $bid=$ARAW[0];
  db_FreeResult($result);
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap2 and $VERSION.sec=$sec2"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ʈwd߿~AO $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $eid=$ARAW[0];
  db_FreeResult($result);
  $BLIMIT="$VERSION.id>=$bid and $VERSION.id<=$eid";
 }
 elseif (isset($sec))  //# mt 1:1-3,4,8
   {
	if (strstr($sec,","))
	{
	    $tok = strtok ($sec,",");
	    $SLIMIT="";
	    while (!($tok === FALSE)) // #mt 1:1,2,5,7
	    {
		if (strstr($tok,"-")) // #mt 1:1-3,6,10
		  $SLIMIT=$SLIMIT.parsed($VERSION,$tok);
		else 
		   $SLIMIT=$SLIMIT."or $VERSION.sec=$tok ";
	        $tok = strtok (",");
            }
	    $SLIMIT=substr($SLIMIT,2);
	    $BLIMIT="$VERSION.chap=$chap and ( $SLIMIT )";
	}
	elseif (strstr($sec,"-"))
        {
	    $tok = strtok ($sec,"-");
	    $BLIMIT="$VERSION.chap=$chap and ($VERSION.sec>=$tok and ";
	    $tok = strtok ("-");
	    $BLIMIT=$BLIMIT."$VERSION.sec<=$tok)";
	}
	else
		$BLIMIT="$VERSION.chap=$chap and $VERSION.sec=$sec";
   }
 else $BLIMIT="$VERSION.chap=$chap"; //normal
 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echo "@ $numrow AƤӦhFAЭקd߱AdI";
	exit;
   }
 if ($numrow==0)
   {
   	echo "dơAЭקd߱AdI";
	exit;
   }
 $numfield=db_NumFields($result);
 /****uLX *****/
 $TEXTT="";
 for($a=0;$a<$numrow;$a++)
   {
      $ARAW=db_fetch_row($result,$a); //Ū@O
      $special=htmlspecialchars($ARAW[2]);
      $TEXTT=$TEXTT.$special;
   }
   return $TEXTT;
}
?>

==> cbol-3.0.tgz: cbol-3.0/lec/subread.php <==
<?php
 /**** @ܼ ********/
  //W
 require("config.php");
 $PROGNAME="read.php";
  //TableXSOѼ
  //C@
 $PGNUM=500;//ϥ@藍|500`
 // Primary Key	
 $PKEY="oid";
 /******** parse  #mt 1:1-3 *****/
 function parsed($VERSION,$tok)
 {
      $LIMIT="";
      $gtok=split("-",$tok);
      //$gtok = strtok ($tok,"-");
      $gtok[0]=(int) $gtok[0];
      $gtok[1]=(int) $gtok[1];
      $LIMIT="or ($VERSION.sec>=$gtok[0] and $VERSION.sec<=$gtok[1]) ";
      return($LIMIT);
 }
 function outbible($db_conn,$VERSION,$chineses,$chap,$sec,$chap2,$sec2)
{
 if (!isset($VERSION)) $VERSION="unv";
 if (!isset($strongflag)) $strongflag=0;
 if ($strongflag) $sf=0;
 else $sf=1;
 if (!isset($TABFLAG)) $TABFLAG=0;
 if ($TABFLAG) $TF=0;
 else $TF=1;
  $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 /*****TwO_IDܼ*******/
 if (isset($id))
 {
  $QID="select main.chineses, $VERSION.chap from $VERSION,main where main.engs=$VERSION.engs and $VERSION.id=$id"; 

  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ʈwd߿~AO $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $chineses=$ARAW[0];
  $chap=$ARAW[1];
  db_FreeResult($result);
 }
 
  //QueryO
 if ($chap2>0)  //# mt 1:1-3:4
 {
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap and $VERSION.sec=$sec"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ʈwd߿~AO $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $bid=$ARAW[0];
  db_FreeResult($result);
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap2 and $VERSION.sec=$sec2"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ʈwd߿~AO $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $eid=$ARAW[0];
  db_FreeResult($result);
  $BLIMIT="$VERSION.id>=$bid and $VERSION.id<=$eid";
 }
 elseif (isset($sec))  //# mt 1:1-3,4,8
   {
	if (strstr($sec,","))
	{
	    $tok = strtok ($sec,",");
	    $SLIMIT="";
	    while (!($tok === FALSE)) // #mt 1:1,2,5,7
	    {
		if (strstr($tok,"-")) // #mt 1:1-3,6,10
		  $SLIMIT=$SLIMIT.parsed($VERSION,$tok);
		else 
		{
		   $tok=(int) $tok;
		   $SLIMIT=$SLIMIT."or $VERSION.sec=$tok ";
		}
	        $tok = strtok (",");
            }
	    $SLIMIT=substr($SLIMIT,2);
	    $BLIMIT="$VERSION.chap=$chap and ( $SLIMIT )";
	}
	elseif (strstr($sec,"-"))
        {
	    $tok = (int) strtok ($sec,"-");
	    $BLIMIT="$VERSION.chap=$chap and ($VERSION.sec>=$tok and ";
	    $tok = (int) strtok ("-");
	    $BLIMIT=$BLIMIT."$VERSION.sec<=$tok)";
	}
	else
		$BLIMIT="$VERSION.chap=$chap and $VERSION.sec=$sec";
   }
 else $BLIMIT="$VERSION.chap=$chap"; //normal
 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echo "@ $numrow AƤӦhFAЭקd߱AdI";
	exit;
   }
 if ($numrow==0)
   {
   	echo "dơAЭקd߱AdI";
	exit;
   }
 $numfield=db_NumFields($result);
 /****uLX *****/
 $TEXTT="";
 for($a=0;$a<$numrow;$a++)
   {
      $ARAW=db_fetch_row($result,$a); //Ū@O
      $special=htmlspecialchars($ARAW[2]);
      $TEXTT=$TEXTT.$special;
   }
   return $TEXTT;
}
?>
